Documentation
¶
Index ¶
- func DefaultConvertToNumber[T any](value any) T
- func DefaultLessComparer[T any](t1, t2 T) bool
- func DefaultMoreComparer[T any](t1, t2 T) bool
- func IsEmptyOrNil[T any](t []T) bool
- func IsFloat(i any) bool
- func IsInt(i any) bool
- func IsNumber(i any) bool
- func IsUint(i any) bool
- type Accumulator
- type CombinationSelector
- type Comparer
- type GetHashCode
- type GroupBySelector
- type KeyValData
- type SingleSelector
- type SingleSelectorFull
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DefaultConvertToNumber ¶
DefaultConvertToNumber
func DefaultLessComparer ¶
DefaultLessComparer is the default compare when the first one is smaller than the second one
func DefaultMoreComparer ¶
DefaultMoreComparer is the default compare when the first one is greater than the second one
func IsEmptyOrNil ¶
Types ¶
type Accumulator ¶
Accumulator represents an accumulator function to be invoked on each element.
type CombinationSelector ¶
CombinationSelector represents a function that combines two objects under T, K type to another object
type Comparer ¶
Comparer represents a function that compares two variables of type T, there will be 3 cases: smaller, equal, larger depending on the purpose of use
type GetHashCode ¶
GetHashCode represents a function that gets hashcode from an object
type GroupBySelector ¶
GroupBySelector represents a function that combines two objects under T, []K type to another object
type KeyValData ¶ added in v1.1.1
type KeyValData[K, V any] struct { Key K Val V }
type SingleSelector ¶
SingleSelector represents a function that converts an object under T type to another object
type SingleSelectorFull ¶
SingleSelectorFull represents a function that converts an object under T type to another object under K type